@@ -19,7 +19,7 @@ under Wine is to use the DPT database engine on a platform other than Microsoft
 Windows.
 """
 
-if __name__ == '__main__':
+if __name__ == "__main__":
 
     from . import APPLICATION_NAME
 
@@ -28,35 +28,37 @@ if __name__ == '__main__':
             start_application_exception,
             stop_application,
             application_exception,
-            )
+        )
     except Exception as error:
         import tkinter.messagebox
+
         try:
-           tkinter.messagebox.showerror(
-               title='Start Exception',
-               message='.\n\nThe reported exception is:\n\n'.join(
-                   ('Unable to import solentware_misc.gui.startstop module',
-                    str(error))),
-               )
+            tkinter.messagebox.showerror(
+                title="Start Exception",
+                message=".\n\nThe reported exception is:\n\n".join(
+                    (
+                        "Unable to import solentware_misc.gui.startstop module",
+                        str(error),
+                    )
+                ),
+            )
         except:
             pass
-        raise SystemExit('Unable to import start application utilities')
+        raise SystemExit("Unable to import start application utilities")
     try:
         from .gui.chess import Chess
     except Exception as error:
         start_application_exception(
-            error,
-            appname=APPLICATION_NAME,
-            action='import')
-        raise SystemExit(' import '.join(('Unable to', APPLICATION_NAME)))
+            error, appname=APPLICATION_NAME, action="import"
+        )
+        raise SystemExit(" import ".join(("Unable to", APPLICATION_NAME)))
     try:
         app = Chess(allowcreate=True)
     except Exception as error:
         start_application_exception(
-            error,
-            appname=APPLICATION_NAME,
-            action='initialise')
-        raise SystemExit(' initialise '.join(('Unable to', APPLICATION_NAME)))
+            error, appname=APPLICATION_NAME, action="initialise"
+        )
+        raise SystemExit(" initialise ".join(("Unable to", APPLICATION_NAME)))
     try:
         app.root.mainloop()
     except SystemExit:
@@ -68,4 +70,5 @@ if __name__ == '__main__':
             app,
             app.root,
             title=APPLICATION_NAME,
-            appname=APPLICATION_NAME)
+            appname=APPLICATION_NAME,
+        )
