@@ -24,45 +24,47 @@ games. Two million games is large: but 10,000 games is not large.
 
 """
 
-if __name__ == '__main__':
+if __name__ == "__main__":
 
     from . import APPLICATION_NAME
 
-    application_name = ' '.join((APPLICATION_NAME, '(WineDPTChunk)'))
+    application_name = " ".join((APPLICATION_NAME, "(WineDPTChunk)"))
     try:
         from solentware_misc.gui.startstop import (
             start_application_exception,
             stop_application,
             application_exception,
-            )
+        )
     except Exception as error:
         import tkinter.messagebox
+
         try:
-           tkinter.messagebox.showerror(
-               title='Start Exception',
-               message='.\n\nThe reported exception is:\n\n'.join(
-                   ('Unable to import solentware_misc.gui.startstop module',
-                    str(error))),
-               )
+            tkinter.messagebox.showerror(
+                title="Start Exception",
+                message=".\n\nThe reported exception is:\n\n".join(
+                    (
+                        "Unable to import solentware_misc.gui.startstop module",
+                        str(error),
+                    )
+                ),
+            )
         except:
             pass
-        raise SystemExit('Unable to import start application utilities')
+        raise SystemExit("Unable to import start application utilities")
     try:
         from .gui.chess import Chess
     except Exception as error:
         start_application_exception(
-            error,
-            appname=application_name,
-            action='import')
-        raise SystemExit(' import '.join(('Unable to', application_name)))
+            error, appname=application_name, action="import"
+        )
+        raise SystemExit(" import ".join(("Unable to", application_name)))
     try:
         app = Chess(allowcreate=True, dptchunksize=5000)
     except Exception as error:
         start_application_exception(
-            error,
-            appname=application_name,
-            action='initialise')
-        raise SystemExit(' initialise '.join(('Unable to', application_name)))
+            error, appname=application_name, action="initialise"
+        )
+        raise SystemExit(" initialise ".join(("Unable to", application_name)))
     try:
         app.root.mainloop()
     except SystemExit:
@@ -74,4 +76,5 @@ if __name__ == '__main__':
             app,
             app.root,
             title=application_name,
-            appname=application_name)
+            appname=application_name,
+        )
