@@ -17,6 +17,5 @@ from ..basecore.analysis import Analysis
 
 
 class AnalysisDS(Analysis, DataSourceCursor):
-    
-    """Combine a DPT DataSourceCursor with Analysis.
-    """
+
+    """Combine a DPT DataSourceCursor with Analysis."""
