@@ -22,7 +22,7 @@ from dptdb.dptapi import (
     FILEDISP_OLD,
     FISTAT_DEFERRED_UPDATES,
     APIContextSpecification,
-    )
+)
 
 from solentware_base import dptdu_database
 from solentware_base.core.constants import (
@@ -31,14 +31,14 @@ from solentware_base.core.constants import (
     BSIZE,
     DSIZE,
     TABLE_B_SIZE,
-    )
+)
 
 from ..core.filespec import (
     FileSpec,
     GAMES_FILE_DEF,
     PIECES_PER_POSITION,
     POSITIONS_PER_GAME,
-    )
+)
 from ..core.chessrecord import ChessDBrecordGameImport
 
 # Current practical way to determine if running on Wine, taking advantage of
@@ -58,14 +58,19 @@ from ..core.chessrecord import ChessDBrecordGameImport
 # DB_SEGMENT_SIZE has no effect on processing apart from report points.
 DB_SEGMENT_SIZE = 65536
 import multiprocessing
+
 try:
     multiprocessing.Queue()
-    _DEFERRED_UPDATE_POINTS = DB_SEGMENT_SIZE - 1,
+    _DEFERRED_UPDATE_POINTS = (DB_SEGMENT_SIZE - 1,)
 except OSError:
     _DEFERRED_UPDATE_POINTS = tuple(
-        [i for i in range(DB_SEGMENT_SIZE//8-1,
-                          DB_SEGMENT_SIZE,
-                          DB_SEGMENT_SIZE//8)])
+        [
+            i
+            for i in range(
+                DB_SEGMENT_SIZE // 8 - 1, DB_SEGMENT_SIZE, DB_SEGMENT_SIZE // 8
+            )
+        ]
+    )
 del multiprocessing
 del DB_SEGMENT_SIZE
 CHUNKGAMES = 6144
@@ -79,33 +84,36 @@ def chess_dptdu(
     dbpath,
     pgnpaths,
     file_records=None,
-    reporter=lambda text, timestamp=True: None):
+    reporter=lambda text, timestamp=True: None,
+):
     """Open database, import games and close database."""
     cdb = ChessDatabase(dbpath, allowcreate=True)
     importer = ChessDBrecordGameImport()
     cdb.open_database(files=file_records)
     for pp in pgnpaths:
-        s = open(pp, 'r', encoding='iso-8859-1')
+        s = open(pp, "r", encoding="iso-8859-1")
         importer.import_pgn(cdb, s, pp, reporter=reporter)
         s.close()
-    reporter('Finishing import: please wait.')
-    reporter('', timestamp=False)
+    reporter("Finishing import: please wait.")
+    reporter("", timestamp=False)
     cdb.close_database_contexts(files=file_records)
     cdb.open_database_contexts(files=file_records)
     status = True
-    for f in cdb.specification.keys() if file_records is None else file_records:
-        if (FISTAT_DEFERRED_UPDATES !=
-            cdb.table[f].get_file_parameters(cdb.dbenv)['FISTAT'][0]):
+    for f in (
+        cdb.specification.keys() if file_records is None else file_records
+    ):
+        if (
+            FISTAT_DEFERRED_UPDATES
+            != cdb.table[f].get_file_parameters(cdb.dbenv)["FISTAT"][0]
+        ):
             status = False
     cdb.close_database_contexts()
     return status
 
 
 def chess_dptdu_chunks(
-    dbpath,
-    pgnpaths,
-    file_records,
-    reporter=lambda text, timestamp=True: None):
+    dbpath, pgnpaths, file_records, reporter=lambda text, timestamp=True: None
+):
     """Open database, import games in fixed chunks and close database."""
 
     def write_chunk(sample=None):
@@ -113,10 +121,8 @@ def chess_dptdu_chunks(
 
         # chess_dptdu_chunks does the reporting so do not pass reporter to
         # import_pgn, but the name of the source file is mandantory.
-        importer.import_pgn(cdb,
-                            StringIO(''.join(games)),
-                            pp)
-            
+        importer.import_pgn(cdb, StringIO("".join(games)), pp)
+
         cdb.close_database_contexts()
         games[:] = []
 
@@ -129,38 +135,46 @@ def chess_dptdu_chunks(
     records = file_records
     for pp in pgnpaths:
         cdb._text_file_size = os.path.getsize(pp)
-        inp = open(pp, 'r', encoding='iso-8859-1')
+        inp = open(pp, "r", encoding="iso-8859-1")
         line = inp.readline()
-        reporter('Extracting games from ' + pp)
+        reporter("Extracting games from " + pp)
         count = 0
         while line:
             if line.startswith(newgamestring):
-                games.append(''.join(gamelines))
+                games.append("".join(gamelines))
                 gamelines = []
                 if len(games) >= CHUNKGAMES:
                     records = write_chunk(sample=records)
                     count += 1
-                    reporter(' '.join(('Chunk',
-                                       str(count),
-                                       'written, total games added:',
-                                       str(CHUNKGAMES * count),
-                                       )))
+                    reporter(
+                        " ".join(
+                            (
+                                "Chunk",
+                                str(count),
+                                "written, total games added:",
+                                str(CHUNKGAMES * count),
+                            )
+                        )
+                    )
             gamelines.append(line)
             line = inp.readline()
         inp.close()
         if gamelines:
-            games.append(''.join(gamelines))
+            games.append("".join(gamelines))
             records = write_chunk(sample=records)
-        reporter('Extraction from ' + pp + ' done')
-        reporter('', timestamp=False)
-    reporter('Finishing import: please wait.')
-    reporter('', timestamp=False)
+        reporter("Extraction from " + pp + " done")
+        reporter("", timestamp=False)
+    reporter("Finishing import: please wait.")
+    reporter("", timestamp=False)
     cdb.open_database_contexts(files=file_records)
     status = True
     for f in file_records:
-        if (FISTAT_DEFERRED_UPDATES !=
-            cdb.get_database_instance(
-                f, None).get_file_parameters(cdb.dbenv)['FISTAT'][0]):
+        if (
+            FISTAT_DEFERRED_UPDATES
+            != cdb.get_database_instance(f, None).get_file_parameters(
+                cdb.dbenv
+            )["FISTAT"][0]
+        ):
             status = False
     cdb.close_database_contexts()
     return status
@@ -171,8 +185,9 @@ class ChessDatabaseDeferred:
     """Provide deferred update methods for a database of games of chess.
 
     Subclasses must include a subclass of dptbase.Database as a superclass.
-    
+
     """
+
     # ChessDatabaseDeferred.deferred_update_points is not needed in DPT, like
     # the similar attribute in chessdbbitdu.ChessDatabase for example, because
     # DPT does it's own memory management for deferred updates.
@@ -190,7 +205,7 @@ class ChessDatabaseDeferred:
         allowcreate == False - remove file descriptions from FileSpec so
         that superclass cannot create them.
         Other arguments are passed through to superclass __init__.
-        
+
         """
         ddnames = FileSpec(**kargs)
         # Deferred update for games file only
@@ -198,27 +213,26 @@ class ChessDatabaseDeferred:
             if dd != GAMES_FILE_DEF:
                 del ddnames[dd]
 
-        if not kargs.get('allowcreate', False):
+        if not kargs.get("allowcreate", False):
             try:
                 for dd in ddnames:
                     if FILEDESC in ddnames[dd]:
                         del ddnames[dd][FILEDESC]
             except:
-                if __name__ == '__main__':
+                if __name__ == "__main__":
                     raise
                 else:
-                    raise ChessdptduError('DPT description invalid')
+                    raise ChessdptduError("DPT description invalid")
 
         try:
             super(ChessDatabaseDeferred, self).__init__(
-                ddnames,
-                databasefolder,
-                **kargs)
+                ddnames, databasefolder, **kargs
+            )
         except ChessdptduError:
-            if __name__ == '__main__':
+            if __name__ == "__main__":
                 raise
             else:
-                raise ChessdptduError('DPT description invalid')
+                raise ChessdptduError("DPT description invalid")
 
         # Retain import estimates for increase size by button actions
         self._import_estimates = None
@@ -233,9 +247,10 @@ class ChessDatabaseDeferred:
         super().open_database(files=files)
         vr = self.dbenv.Core().GetViewerResetter()
         for dbo in self.table.values():
-            if vr.ViewAsInt(
-                'FISTAT',
-                dbo.opencontext) != FISTAT_DEFERRED_UPDATES:
+            if (
+                vr.ViewAsInt("FISTAT", dbo.opencontext)
+                != FISTAT_DEFERRED_UPDATES
+            ):
                 break
         else:
             if files is None:
@@ -243,19 +258,21 @@ class ChessDatabaseDeferred:
             self.increase_database_size(files=files)
             return
         self.close_database()
-        raise ChessdptduError('A file is not in deferred update mode')
-    
+        raise ChessdptduError("A file is not in deferred update mode")
+
     def open_context_prepare_import(self):
         """Open all files normally"""
         super().open_database()
-    
+
     def get_archive_names(self, files=()):
         """Return specified files and existing operating system files"""
         specs = {f for f in files if f in self.table}
-        names = [v.file for k, v in self.table.items()
-                 if k in specs]
-        exists = [os.path.basename(n)
-                  for n in names if os.path.exists('.'.join((n, 'bz2')))]
+        names = [v.file for k, v in self.table.items() if k in specs]
+        exists = [
+            os.path.basename(n)
+            for n in names
+            if os.path.exists(".".join((n, "bz2")))
+        ]
         return (names, exists)
 
     def get_pages_for_record_counts(self, counts=(0, 0)):
@@ -264,7 +281,7 @@ class ChessDatabaseDeferred:
         return (
             counts[0] // brecppg,
             (counts[1] * self.table[GAMES_FILE_DEF].btod_factor) // brecppg,
-            )
+        )
 
     def archive(self, flag=None, names=None):
         """Write a bz2 backup of file containing games.
@@ -279,10 +296,10 @@ class ChessDatabaseDeferred:
         if flag:
             for n in names:
                 c = bz2.BZ2Compressor()
-                archiveguard = '.'.join((n, 'grd'))
-                archivename = '.'.join((n, 'bz2'))
-                fi = open(n, 'rb')
-                fo = open(archivename, 'wb')
+                archiveguard = ".".join((n, "grd"))
+                archivename = ".".join((n, "bz2"))
+                fi = open(n, "rb")
+                fo = open(archivename, "wb")
                 inp = fi.read(10000000)
                 while inp:
                     co = c.compress(inp)
@@ -294,7 +311,7 @@ class ChessDatabaseDeferred:
                     fo.write(co)
                 fo.close()
                 fi.close()
-                c = open(archiveguard, 'wb')
+                c = open(archiveguard, "wb")
                 c.close()
         return True
 
@@ -304,8 +321,8 @@ class ChessDatabaseDeferred:
             return False
         if flag:
             for n in names:
-                archiveguard = '.'.join((n, 'grd'))
-                archivename = '.'.join((n, 'bz2'))
+                archiveguard = ".".join((n, "grd"))
+                archivename = ".".join((n, "bz2"))
                 try:
                     os.remove(archiveguard)
                 except:
@@ -322,17 +339,16 @@ class ChessDatabaseDeferred:
             files = dict()
         fs = dict()
         for k, v in self.get_database_parameters(
-            files=list(files.keys())).items():
-            fs[k] = (v['BSIZE'], v['BHIGHPG'], v['DSIZE'], v['DPGSUSED'])
+            files=list(files.keys())
+        ).items():
+            fs[k] = (v["BSIZE"], v["BHIGHPG"], v["DSIZE"], v["DPGSUSED"])
         fi = self.get_database_increase(files=files)
         self.close_database_contexts()
         return fs, fi
 
-    def add_import_buttons(self,
-                           master,
-                           try_command_wrapper,
-                           try_event_wrapper,
-                           widget):
+    def add_import_buttons(
+        self, master, try_command_wrapper, try_event_wrapper, widget
+    ):
         """Add button actions for DPT to Import dialogue.
 
         Increase data and index space available.
@@ -340,20 +356,20 @@ class ChessDatabaseDeferred:
         """
         index = tkinter.Button(
             master=master,
-            text='Increase Index',
+            text="Increase Index",
             underline=13,
-            command=try_command_wrapper(
-                self._increase_index, master))
+            command=try_command_wrapper(self._increase_index, master),
+        )
         index.pack(side=tkinter.RIGHT, padx=12)
-        widget.bind('<Alt-x>', try_event_wrapper(self._increase_index))
+        widget.bind("<Alt-x>", try_event_wrapper(self._increase_index))
         data = tkinter.Button(
             master=master,
-            text='Increase Data',
+            text="Increase Data",
             underline=9,
-            command=try_command_wrapper(
-                self._increase_data, master))
+            command=try_command_wrapper(self._increase_data, master),
+        )
         data.pack(side=tkinter.RIGHT, padx=12)
-        widget.bind('<Alt-d>', try_event_wrapper(self._increase_data))
+        widget.bind("<Alt-d>", try_event_wrapper(self._increase_data))
 
     def _increase_data(self, event=None):
         """Add maximum of current free space and default size to Table B.
@@ -365,41 +381,55 @@ class ChessDatabaseDeferred:
         self.open_context_normal(files=(GAMES_FILE_DEF,))
         increase_done = False
         for k, v in self.get_database_parameters(
-            files=(GAMES_FILE_DEF,)).items():
-            bsize = v['BSIZE']
-            bused = max(0, v['BHIGHPG'])
+            files=(GAMES_FILE_DEF,)
+        ).items():
+            bsize = v["BSIZE"]
+            bused = max(0, v["BHIGHPG"])
             bneeded = self.get_pages_for_record_counts(
-                self._notional_record_counts[k])[0]
+                self._notional_record_counts[k]
+            )[0]
             bincrease = min(bneeded * 2, bsize - bused)
-            message = ''.join(
-                ('The free data size of the ',
-                 k,
-                 ' file will be increased from ',
-                 str(bsize - bused),
-                 ' pages to ',
-                 str(bincrease + bsize - bused),
-                 ' pages.'))
+            message = "".join(
+                (
+                    "The free data size of the ",
+                    k,
+                    " file will be increased from ",
+                    str(bsize - bused),
+                    " pages to ",
+                    str(bincrease + bsize - bused),
+                    " pages.",
+                )
+            )
             if len(self.table[k].get_extents()) % 2 == 0:
-                 message = ''.join(
-                     (message,
-                      '\n\nAt present it is better to do index increases ',
-                      'first for this file, if you need to do any, because ',
-                      'a new extent (fragment) would not be needed.'))
+                message = "".join(
+                    (
+                        message,
+                        "\n\nAt present it is better to do index increases ",
+                        "first for this file, if you need to do any, because ",
+                        "a new extent (fragment) would not be needed.",
+                    )
+                )
             if tkinter.messagebox.askyesno(
-                title='Increase Data Size',
-                message=''.join(
-                    (message,
-                     '\n\nDo you want to increase the data size?',
-                     ))):
+                title="Increase Data Size",
+                message="".join(
+                    (
+                        message,
+                        "\n\nDo you want to increase the data size?",
+                    )
+                ),
+            ):
                 increase_done = True
                 self.table[k].opencontext.Increase(bincrease, False)
         if increase_done:
             self._reporter.append_text(
-                ' '.join(
-                    ('Recalculation of planned database size increases',
-                     'after data size increase by user action.',
-                     )))
-            self._reporter.append_text_only('')
+                " ".join(
+                    (
+                        "Recalculation of planned database size increases",
+                        "after data size increase by user action.",
+                    )
+                )
+            )
+            self._reporter.append_text_only("")
             self._report_plans_for_estimate()
         self.close_database_contexts()
 
@@ -413,41 +443,55 @@ class ChessDatabaseDeferred:
         self.open_context_normal(files=(GAMES_FILE_DEF,))
         increase_done = False
         for k, v in self.get_database_parameters(
-            files=(GAMES_FILE_DEF,)).items():
-            dsize = v['DSIZE']
-            dused = v['DPGSUSED']
+            files=(GAMES_FILE_DEF,)
+        ).items():
+            dsize = v["DSIZE"]
+            dused = v["DPGSUSED"]
             dneeded = self.get_pages_for_record_counts(
-                self._notional_record_counts[k])[1]
+                self._notional_record_counts[k]
+            )[1]
             dincrease = min(dneeded * 2, dsize - dused)
-            message = ''.join(
-                ('The free index size of the ',
-                 k,
-                 ' file will be increased from ',
-                 str(dsize - dused),
-                 ' pages to ',
-                 str(dincrease + dsize - dused),
-                 ' pages.'))
+            message = "".join(
+                (
+                    "The free index size of the ",
+                    k,
+                    " file will be increased from ",
+                    str(dsize - dused),
+                    " pages to ",
+                    str(dincrease + dsize - dused),
+                    " pages.",
+                )
+            )
             if len(self.table[k].get_extents()) % 2 != 0:
-                 message = ''.join(
-                     (message,
-                      '\n\nAt present it is better to do data increases ',
-                      'first for this file, if you need to do any, because ',
-                      'a new extent (fragment) would not be needed.'))
+                message = "".join(
+                    (
+                        message,
+                        "\n\nAt present it is better to do data increases ",
+                        "first for this file, if you need to do any, because ",
+                        "a new extent (fragment) would not be needed.",
+                    )
+                )
             if tkinter.messagebox.askyesno(
-                title='Increase Index Size',
-                message=''.join(
-                    (message,
-                     '\n\nDo you want to increase the index size?',
-                     ))):
+                title="Increase Index Size",
+                message="".join(
+                    (
+                        message,
+                        "\n\nDo you want to increase the index size?",
+                    )
+                ),
+            ):
                 increase_done = True
                 self.table[k].opencontext.Increase(dincrease, True)
         if increase_done:
             self._reporter.append_text(
-                ' '.join(
-                    ('Recalculation of planned database size increases',
-                     'after index size increase by user action.',
-                     )))
-            self._reporter.append_text_only('')
+                " ".join(
+                    (
+                        "Recalculation of planned database size increases",
+                        "after index size increase by user action.",
+                    )
+                )
+            )
+            self._reporter.append_text_only("")
             self._report_plans_for_estimate()
         self.close_database_contexts()
 
@@ -488,109 +532,123 @@ class ChessDatabaseDeferred:
         append_text_only = self._reporter.append_text_only
         if estimates is not None:
             self._import_estimates = estimates
-        (gamecount,
-         bytes_per_game,
-         positions_per_game,
-         pieces_per_game,
-         errorcount,
-         bytes_per_error,
-         estimate,
-         gamesamplecount,
-         errorsamplecount) = self._import_estimates[:9]
+        (
+            gamecount,
+            bytes_per_game,
+            positions_per_game,
+            pieces_per_game,
+            errorcount,
+            bytes_per_error,
+            estimate,
+            gamesamplecount,
+            errorsamplecount,
+        ) = self._import_estimates[:9]
         brecppg = self.table[GAMES_FILE_DEF].filedesc[BRECPPG]
-        d_count = (
-            (gamecount * (positions_per_game + pieces_per_game)) //
-            (POSITIONS_PER_GAME * (1 + PIECES_PER_POSITION)))
+        d_count = (gamecount * (positions_per_game + pieces_per_game)) // (
+            POSITIONS_PER_GAME * (1 + PIECES_PER_POSITION)
+        )
         if bytes_per_game > (TABLE_B_SIZE // brecppg):
             b_count = int(
-                (gamecount * bytes_per_game) / (TABLE_B_SIZE / brecppg))
+                (gamecount * bytes_per_game) / (TABLE_B_SIZE / brecppg)
+            )
         else:
             b_count = gamecount
         self._notional_record_counts = {
             GAMES_FILE_DEF: (b_count, d_count),
-            }
-        append_text('Current file size and free space:')
+        }
+        append_text("Current file size and free space:")
         free = dict()
         sizes, increases = self.get_database_table_sizes(
-            files=self._notional_record_counts)
+            files=self._notional_record_counts
+        )
         for fn, ds in sizes.items():
             bsize, bused, dsize, dused = ds
             bused = max(0, bused)
             free[fn] = (bsize - bused, dsize - dused)
             append_text_only(fn)
             append_text_only(
-                ' '.join(('Current data area size', str(bsize), 'pages')))
+                " ".join(("Current data area size", str(bsize), "pages"))
+            )
             append_text_only(
-                ' '.join(('Current index area size', str(dsize), 'pages')))
+                " ".join(("Current index area size", str(dsize), "pages"))
+            )
             append_text_only(
-                ' '.join(
-                    ('Current data area free', str(bsize - bused), 'pages')))
+                " ".join(
+                    ("Current data area free", str(bsize - bused), "pages")
+                )
+            )
             append_text_only(
-                ' '.join(
-                    ('Current index area free', str(dsize - dused), 'pages')))
-        append_text_only('')
-        append_text('File space needed for import:')
+                " ".join(
+                    ("Current index area free", str(dsize - dused), "pages")
+                )
+            )
+        append_text_only("")
+        append_text("File space needed for import:")
         for fn, fc in self._notional_record_counts.items():
             append_text_only(fn)
             b, d = self.get_pages_for_record_counts(fc)
             append_text_only(
-                ' '.join(('Estimated', str(b), 'pages needed for data')))
+                " ".join(("Estimated", str(b), "pages needed for data"))
+            )
             append_text_only(
-                ' '.join(('Estimated', str(d), 'pages needed for indexes')))
-        append_text_only('')
-        append_text(
-            'File size increases planned and free space when done:')
+                " ".join(("Estimated", str(d), "pages needed for indexes"))
+            )
+        append_text_only("")
+        append_text("File size increases planned and free space when done:")
         for fn, ti in increases.items():
             bi, di = ti
             bf, df = free[fn]
             append_text_only(fn)
             append_text_only(
-                ' '.join(('Data area increase', str(bi), 'pages')))
+                " ".join(("Data area increase", str(bi), "pages"))
+            )
             append_text_only(
-                ' '.join(('Index area increase', str(di), 'pages')))
+                " ".join(("Index area increase", str(di), "pages"))
+            )
             append_text_only(
-                ' '.join(('Data area free', str(bi + bf), 'pages')))
+                " ".join(("Data area free", str(bi + bf), "pages"))
+            )
             append_text_only(
-                ' '.join(('Index area free', str(di + df), 'pages')))
-        append_text_only('')
+                " ".join(("Index area free", str(di + df), "pages"))
+            )
+        append_text_only("")
         append_text_only(
-            ''.join(
-                ('Comparison of the required and free data or index ',
-                 'space may justify using the Increase Data and, or, ',
-                 'Increase Index actions to get more space immediately ',
-                 'given your knowledge of the PGN file being imported.',
-                 )))
-        append_text_only('')
-        append_text_only('')
+            "".join(
+                (
+                    "Comparison of the required and free data or index ",
+                    "space may justify using the Increase Data and, or, ",
+                    "Increase Index actions to get more space immediately ",
+                    "given your knowledge of the PGN file being imported.",
+                )
+            )
+        )
+        append_text_only("")
+        append_text_only("")
 
 
 class ChessDatabase(ChessDatabaseDeferred, dptdu_database.Database):
 
-    """Provide single-step deferred update for a database of games of chess.
-    """
+    """Provide single-step deferred update for a database of games of chess."""
 
 
-if __name__ == '__main__':
-
+if __name__ == "__main__":
 
     import tkinter.ttk
     import tkinter.filedialog
 
     root = tkinter.Tk()
-    root.wm_title('Sample do_deferred_updates')
+    root.wm_title("Sample do_deferred_updates")
     frame = tkinter.ttk.Frame(master=root)
     text = tkinter.Text(master=frame, wrap=tkinter.WORD)
     frame.pack(fill=tkinter.Y, expand=tkinter.TRUE)
     text.pack(fill=tkinter.BOTH, expand=tkinter.TRUE)
     databasepath = tkinter.filedialog.askdirectory(
-        parent=root,
-        title='Select database directory',
-        initialdir='~')
+        parent=root, title="Select database directory", initialdir="~"
+    )
     if databasepath:
-        text.insert(tkinter.END,
-                    'Database directory: ' + databasepath + '\n')
+        text.insert(tkinter.END, "Database directory: " + databasepath + "\n")
     else:
-        text.insert(tkinter.END, 'No database selected\n')
+        text.insert(tkinter.END, "No database selected\n")
 
     def quit_(*a):
         root.destroy()
@@ -604,46 +662,40 @@ if __name__ == '__main__':
 
         def do_function(dbp, fp):
             chess_dptdu(dbp, fp)
-            text.insert(tkinter.END,
-                        'Process finished\nProceed or Quit?\n\n')
+            text.insert(tkinter.END, "Process finished\nProceed or Quit?\n\n")
 
         def proceed(*a):
             global filepath
             if filepath:
-                text.insert(tkinter.END,
-                            '\nProcess started, please wait.\n')
+                text.insert(tkinter.END, "\nProcess started, please wait.\n")
                 text.after(1, do_function, *(databasepath, [filepath]))
                 filepath = None
             elif databasepath:
                 filepath = tkinter.filedialog.askopenfilename(
-                    parent=root,
-                    title='Select data file',
-                    initialdir='~')
+                    parent=root, title="Select data file", initialdir="~"
+                )
                 if filepath:
-                    text.insert(tkinter.END, 'Data file: ' + filepath + '\n')
+                    text.insert(tkinter.END, "Data file: " + filepath + "\n")
                 else:
-                    text.insert(tkinter.END, 'No data file selected\n')
-        
+                    text.insert(tkinter.END, "No data file selected\n")
+
         menu.add_separator()
-        menu.add_command(label='Proceed',
-                         command=proceed,
-                         accelerator='Alt F2')
-        menu.add_command(label='Quit',
-                         command=quit_,
-                         accelerator='Alt F11')
+        menu.add_command(
+            label="Proceed", command=proceed, accelerator="Alt F2"
+        )
+        menu.add_command(label="Quit", command=quit_, accelerator="Alt F11")
         menu.add_separator()
-        text.insert(tkinter.END,
-                    '\nRight-click to proceed after each step\n\n')
-        text.bind('<Alt-KeyPress-F2>', proceed)
-        text.bind('<Alt-KeyPress-F11>', quit_)
-        text.bind('<ButtonPress-3>', show_menu)
+        text.insert(
+            tkinter.END, "\nRight-click to proceed after each step\n\n"
+        )
+        text.bind("<Alt-KeyPress-F2>", proceed)
+        text.bind("<Alt-KeyPress-F11>", quit_)
+        text.bind("<ButtonPress-3>", show_menu)
     else:
         menu.add_separator()
-        menu.add_command(label='Quit',
-                         command=quit_,
-                         accelerator='Alt F11')
+        menu.add_command(label="Quit", command=quit_, accelerator="Alt F11")
         menu.add_separator()
-        text.insert(tkinter.END, '\nRight-click to quit\n')
-        text.bind('<Alt-KeyPress-F11>', quit_)
-        text.bind('<ButtonPress-3>', show_menu)
+        text.insert(tkinter.END, "\nRight-click to quit\n")
+        text.bind("<Alt-KeyPress-F11>", quit_)
+        text.bind("<ButtonPress-3>", show_menu)
     root.mainloop()
