@@ -17,6 +17,5 @@ from ..basecore.selection import Selection
 
 
 class SelectionDS(Selection, DataSourceCursor):
-    
-    """Combine a DPT DataSourceCursor with Selection.
-    """
+
+    """Combine a DPT DataSourceCursor with Selection."""
