@@ -15,7 +15,7 @@ import tkinter.messagebox
 import queue
 import time
 
-from solentware_misc.api import callthreadqueue
+from solentware_misc.core import callthreadqueue
 from solentware_misc.gui.tasklog import LogText
 from solentware_misc.gui.exceptionhandler import ExceptionHandler
 
@@ -25,7 +25,7 @@ from ..core.pgn import GameUpdateEstimate
 from .. import (
     ERROR_LOG,
     APPLICATION_NAME,
-    )
+)
 from ..core.filespec import GAMES_FILE_DEF
 from .fonts import _get_default_font_actual
 
@@ -55,10 +55,8 @@ class ChessDeferredUpdate(ExceptionHandler):
     """Connect a chess database with User Interface for deferred update."""
 
     def __init__(
-        self,
-        deferred_update_method=None,
-        database_class=None,
-        sample=5000):
+        self, deferred_update_method=None, database_class=None, sample=5000
+    ):
         """Create the database and ChessUI objects.
 
         deferred_update_method - the method to do the import
@@ -76,14 +74,18 @@ class ChessDeferredUpdate(ExceptionHandler):
         self._allow_job = None
         self._import_job = None
         self.database = database_class(
-            sys.argv[1],
-            allowcreate=True,
-            deferupdatefiles={GAMES_FILE_DEF})
+            sys.argv[1], allowcreate=True, deferupdatefiles={GAMES_FILE_DEF}
+        )
 
         self.root = tkinter.Tk()
-        self.root.wm_title(' - '.join(
-            (' '.join((APPLICATION_NAME, 'Import')),
-             os.path.basename(sys.argv[1]))))
+        self.root.wm_title(
+            " - ".join(
+                (
+                    " ".join((APPLICATION_NAME, "Import")),
+                    os.path.basename(sys.argv[1]),
+                )
+            )
+        )
         frame = tkinter.Frame(master=self.root)
         frame.pack(side=tkinter.BOTTOM)
         self.buttonframe = tkinter.Frame(master=frame)
@@ -94,32 +96,41 @@ class ChessDeferredUpdate(ExceptionHandler):
         # some control logic, than wrap the things in a task queue for the main
         # thread to process.  But the presence or absence of the buttons should
         # be the control logic.
-        self._quit_message = ''.join(
-            ('The import has not been started.',
-             '\n\nDo you want to abandon the import?',
-             ))
+        self._quit_message = "".join(
+            (
+                "The import has not been started.",
+                "\n\nDo you want to abandon the import?",
+            )
+        )
         self.cancel = tkinter.Button(
             master=self.buttonframe,
-            #text='Cancel',
-            text='Quit',
+            # text='Cancel',
+            text="Quit",
             underline=0,
             command=self.try_command(
-                #self.quit_before_import_started, self.buttonframe))
-                self.quit_import, self.buttonframe))
+                # self.quit_before_import_started, self.buttonframe))
+                self.quit_import,
+                self.buttonframe,
+            ),
+        )
         self.cancel.pack(side=tkinter.RIGHT, padx=12)
         backup = tkinter.Button(
             master=self.buttonframe,
-            text='Import with Backups',
+            text="Import with Backups",
             underline=12,
             command=self.try_command(
-                self.do_import_with_backup, self.buttonframe))
+                self.do_import_with_backup, self.buttonframe
+            ),
+        )
         backup.pack(side=tkinter.RIGHT, padx=12)
         import_ = tkinter.Button(
             master=self.buttonframe,
-            text='Import',
+            text="Import",
             underline=0,
             command=self.try_command(
-                self.do_import_without_backup, self.buttonframe))
+                self.do_import_without_backup, self.buttonframe
+            ),
+        )
         import_.pack(side=tkinter.RIGHT, padx=12)
 
         # See comment near end of this class definition for explanation of this
@@ -136,32 +147,38 @@ class ChessDeferredUpdate(ExceptionHandler):
             wrap=tkinter.WORD,
             undo=tkinter.FALSE,
             get_app=self,
-            cnf=_get_default_font_actual(tkinter.Text))
+            cnf=_get_default_font_actual(tkinter.Text),
+        )
         self.report.focus_set()
-        self.report.bind('<Alt-b>', self.try_event(self.do_import_with_backup))
-        self.report.bind('<Alt-i>',
-                         self.try_event(self.do_import_without_backup))
-        self.report.bind('<Alt-q>', self.try_event(self.quit_import))
+        self.report.bind("<Alt-b>", self.try_event(self.do_import_with_backup))
+        self.report.bind(
+            "<Alt-i>", self.try_event(self.do_import_without_backup)
+        )
+        self.report.bind("<Alt-q>", self.try_event(self.quit_import))
         self.database.add_import_buttons(
-            self.buttonframe,
-            self.try_command,
-            self.try_event,
-            self.report)
+            self.buttonframe, self.try_command, self.try_event, self.report
+        )
 
         self.report.tag_configure(
-            'margin',
-            lmargin2=tkinter.font.nametofont(
-                self.report.cget('font')).measure('2010-05-23 10:20:57  '))
-        self.tagstart = '1.0'
-        self.report.append_text(''.join(('Importing to database ', sys.argv[1], '.')))
+            "margin",
+            lmargin2=tkinter.font.nametofont(self.report.cget("font")).measure(
+                "2010-05-23 10:20:57  "
+            ),
+        )
+        self.tagstart = "1.0"
         self.report.append_text(
-            'All times quoted assume no other applications running.',
-            timestamp=False)
-        self.report.append_text_only('')
-        self.report.append_text('Estimating number of games in import.')
-        self.report.append_text_only('')
+            "".join(("Importing to database ", sys.argv[1], "."))
+        )
+        self.report.append_text(
+            "All times quoted assume no other applications running.",
+            timestamp=False,
+        )
+        self.report.append_text_only("")
+        self.report.append_text("Estimating number of games in import.")
+        self.report.append_text_only("")
         self.report.pack(
-            side=tkinter.LEFT, fill=tkinter.BOTH, expand=tkinter.TRUE)
+            side=tkinter.LEFT, fill=tkinter.BOTH, expand=tkinter.TRUE
+        )
         self.root.iconify()
         self.root.update()
         self.root.deiconify()
@@ -182,16 +199,16 @@ class ChessDeferredUpdate(ExceptionHandler):
         self.database.open_database()
         try:
             if not self.estimate_games_in_import():
-                self.report.append_text('There are no games to import.')
-                self.report.append_text_only('')
+                self.report.append_text("There are no games to import.")
+                self.report.append_text_only("")
                 return None
             if self.allow_time():
                 self.database.report_plans_for_estimate(
-                    self.get_pgn_file_estimates(),
-                    self.report)
+                    self.get_pgn_file_estimates(), self.report
+                )
                 return True
-            self.report.append_text('Unable to estimate time to do import.')
-            self.report.append_text_only('')
+            self.report.append_text("Unable to estimate time to do import.")
+            self.report.append_text_only("")
             return False
         finally:
             self.database.close_database()
@@ -204,52 +221,60 @@ class ChessDeferredUpdate(ExceptionHandler):
         """
         if not self.estimate_data:
             return False
-        seconds = (self.estimate_data[0] + self.estimate_data[4]
-                   ) * self.estimate_data[9] * _DATABASE_UPDATE_FACTOR
+        seconds = (
+            (self.estimate_data[0] + self.estimate_data[4])
+            * self.estimate_data[9]
+            * _DATABASE_UPDATE_FACTOR
+        )
         minutes, seconds = divmod(round(seconds), 60)
         hours, minutes = divmod(minutes, 60)
         days, hours = divmod(hours, 24)
         duration = []
         if days:
             duration.append(str(days))
-            duration.append('days')
+            duration.append("days")
             if hours:
                 duration.append(str(hours))
-                duration.append('hours')
+                duration.append("hours")
         elif hours:
             duration.append(str(hours))
-            duration.append('hours')
+            duration.append("hours")
             if minutes:
                 duration.append(str(minutes))
-                duration.append('minutes')
+                duration.append("minutes")
         elif minutes:
             duration.append(str(minutes))
-            duration.append('minutes')
+            duration.append("minutes")
             if seconds:
                 duration.append(str(seconds))
-                duration.append('seconds')
+                duration.append("seconds")
         elif seconds > 1:
             duration.append(str(seconds))
-            duration.append('seconds')
+            duration.append("seconds")
         else:
             duration.append(str(1))
-            duration.append('second')
+            duration.append("second")
         self.report.append_text(
-            ''.join(('The estimate is the time taken to process the sample ',
-                     'scaled up to the estimated number of games then ',
-                     'multiplied by ',
-                     str(_DATABASE_UPDATE_FACTOR),
-                     '.  Expect the import to take longer if the database ',
-                     'already contains games: the effect is worse for smaller '
-                     'imports.  Progress reports are made if the import is ',
-                     'large enough.')))
-        self.report.append_text_only('')
+            "".join(
+                (
+                    "The estimate is the time taken to process the sample ",
+                    "scaled up to the estimated number of games then ",
+                    "multiplied by ",
+                    str(_DATABASE_UPDATE_FACTOR),
+                    ".  Expect the import to take longer if the database ",
+                    "already contains games: the effect is worse for smaller "
+                    "imports.  Progress reports are made if the import is ",
+                    "large enough.",
+                )
+            )
+        )
+        self.report.append_text_only("")
         self.report.append_text(
-            ''.join(
-                ('The import is expected to take ',
-                 ' '.join(duration),
-                 '.')))
-        self.report.append_text_only('')
+            "".join(
+                ("The import is expected to take ", " ".join(duration), ".")
+            )
+        )
+        self.report.append_text_only("")
         return True
 
     def do_import_with_backup(self, event=None):
@@ -262,43 +287,50 @@ class ChessDeferredUpdate(ExceptionHandler):
         if self._import_job:
             return
         names, exists = self.database.get_archive_names(
-            files=(GAMES_FILE_DEF,))
+            files=(GAMES_FILE_DEF,)
+        )
         if exists:
             if not tkinter.messagebox.askokcancel(
                 parent=self.root,
-                title='Import Backup',
-                message=''.join(
-                    ('Import backups of the following files already exist.\n\n',
-                     '\n'.join(exists),
-                     '\n\nThis may mean an earlier Import action failed and ',
-                     'has not yet been resolved.\n\nClick "Ok" to delete ',
-                     'these backups and create new ones before doing the ',
-                     'Import.  These backups will be deleted if the Import ',
-                     'succeeds.\n\nClick ',
-                     '"Cancel" to leave things as they are.',
-                     )),
-                ):
+                title="Import Backup",
+                message="".join(
+                    (
+                        "Import backups of the following files already exist.\n\n",
+                        "\n".join(exists),
+                        "\n\nThis may mean an earlier Import action failed and ",
+                        'has not yet been resolved.\n\nClick "Ok" to delete ',
+                        "these backups and create new ones before doing the ",
+                        "Import.  These backups will be deleted if the Import ",
+                        "succeeds.\n\nClick ",
+                        '"Cancel" to leave things as they are.',
+                    )
+                ),
+            ):
                 return
             self.report.append_text(
-                'Backups will be taken before doing the import.')
+                "Backups will be taken before doing the import."
+            )
             self.report.append_text(
-                'These backups will replace the existing backups.',
-                timestamp=False)
+                "These backups will replace the existing backups.",
+                timestamp=False,
+            )
         elif not tkinter.messagebox.askokcancel(
             parent=self.root,
-            title='Import Backup',
-            message=''.join(
-                ('Please confirm the import is to be done with backups.',
-                 )),
-            ):
+            title="Import Backup",
+            message="".join(
+                ("Please confirm the import is to be done with backups.",)
+            ),
+        ):
             return
         else:
             self.report.append_text(
-                'Backups will be taken before doing the import.')
+                "Backups will be taken before doing the import."
+            )
         self.report.append_text(
-            'These backups will be deleted if the import succeeds.',
-            timestamp=False)
-        self.report.append_text_only('')
+            "These backups will be deleted if the import succeeds.",
+            timestamp=False,
+        )
+        self.report.append_text_only("")
         self.run_import(backup=True, names=names)
 
     def do_import_without_backup(self, event=None):
@@ -311,41 +343,47 @@ class ChessDeferredUpdate(ExceptionHandler):
         if self._import_job:
             return
         names, exists = self.database.get_archive_names(
-            files=(GAMES_FILE_DEF,))
+            files=(GAMES_FILE_DEF,)
+        )
         if exists:
             if not tkinter.messagebox.askokcancel(
                 parent=self.root,
-                title='Import Backup',
-                message=''.join(
-                    ('Import backups of the following files already exist.\n\n',
-                     '\n'.join(exists),
-                     '\n\nThis may mean an earlier Import action failed and ',
-                     'has not yet been resolved.\n\nClick "Ok" to delete ',
-                     'these backups and create new ones before doing the ',
-                     'Import.  These backups will be deleted if the Import ',
-                     'succeeds.\n\nClick ',
-                     '"Cancel" to leave things as they are.',
-                     )),
-                ):
+                title="Import Backup",
+                message="".join(
+                    (
+                        "Import backups of the following files already exist.\n\n",
+                        "\n".join(exists),
+                        "\n\nThis may mean an earlier Import action failed and ",
+                        'has not yet been resolved.\n\nClick "Ok" to delete ',
+                        "these backups and create new ones before doing the ",
+                        "Import.  These backups will be deleted if the Import ",
+                        "succeeds.\n\nClick ",
+                        '"Cancel" to leave things as they are.',
+                    )
+                ),
+            ):
                 return
             self.report.append_text(
-                'The import will be done without taking backups.')
-            self.report.append_text_only('')
+                "The import will be done without taking backups."
+            )
+            self.report.append_text_only("")
             self.report.append_text(
-                'Existing backups will be deleted before doing the import.',
-                timestamp=False)
-            self.report.append_text_only('')
+                "Existing backups will be deleted before doing the import.",
+                timestamp=False,
+            )
+            self.report.append_text_only("")
         elif not tkinter.messagebox.askokcancel(
             parent=self.root,
-            title='Import Backup',
-            message=''.join(
-                ('Please confirm the import is to be done without backups.',
-                 )),
-            ):
+            title="Import Backup",
+            message="".join(
+                ("Please confirm the import is to be done without backups.",)
+            ),
+        ):
             return
             self.report.append_text(
-                'The import will be done without taking backups.')
-            self.report.append_text_only('')
+                "The import will be done without taking backups."
+            )
+            self.report.append_text_only("")
         self.run_import(backup=False, names=names)
 
     def estimate_games_in_import(self):
@@ -367,7 +405,7 @@ class ChessDeferredUpdate(ExceptionHandler):
             if gamecount + errorcount >= self.sample:
                 estimate = True
                 break
-            source = open(pp, 'r', encoding='iso-8859-1')
+            source = open(pp, "r", encoding="iso-8859-1")
             try:
                 for rcg in reader.read_games(source):
                     if gamecount + errorcount >= self.sample:
@@ -429,86 +467,108 @@ class ChessDeferredUpdate(ExceptionHandler):
             gamecount,
             errorcount,
             (time_end - time_start) / (gamecount + errorcount),
-            )
+        )
         if estimate:
             self.report.append_text(
-                ' '.join(('Estimated Games:', str(self.estimate_data[0]))))
+                " ".join(("Estimated Games:", str(self.estimate_data[0])))
+            )
             self.report.append_text(
-                ' '.join(('Estimated Errors:', str(self.estimate_data[4]))),
-                timestamp=False)
+                " ".join(("Estimated Errors:", str(self.estimate_data[4]))),
+                timestamp=False,
+            )
             self.report.append_text(
-                ' '.join(('Sample Games:', str(gamecount))),
-                timestamp=False)
+                " ".join(("Sample Games:", str(gamecount))), timestamp=False
+            )
             self.report.append_text(
-                ' '.join(('Sample Errors:', str(errorcount))),
-                timestamp=False)
+                " ".join(("Sample Errors:", str(errorcount))), timestamp=False
+            )
         else:
             self.report.append_text(
-                'The import is small so all games are counted.')
+                "The import is small so all games are counted."
+            )
             self.report.append_text(
-                ' '.join(('Games in import:', str(gamecount))),
-                timestamp=False)
+                " ".join(("Games in import:", str(gamecount))), timestamp=False
+            )
             self.report.append_text(
-                ' '.join(('Errors in import:', str(errorcount))),
-                timestamp=False)
+                " ".join(("Errors in import:", str(errorcount))),
+                timestamp=False,
+            )
         self.report.append_text(
-            ' '.join(('Bytes per game:', str(bytes_per_game))),
-            timestamp=False)
+            " ".join(("Bytes per game:", str(bytes_per_game))), timestamp=False
+        )
         self.report.append_text(
-            ' '.join(('Bytes per error:', str(bytes_per_error))),
-            timestamp=False)
+            " ".join(("Bytes per error:", str(bytes_per_error))),
+            timestamp=False,
+        )
         self.report.append_text(
-            ' '.join(('Positions per game:', str(positions_per_game))),
-            timestamp=False)
+            " ".join(("Positions per game:", str(positions_per_game))),
+            timestamp=False,
+        )
 
         # positions_per_game == 0 if there are no valid games.
-        ppp = 'Not a number'
-        for c, t in ((pieces_per_game, 'Pieces per position:'),
-                     (piecetypes_per_game, 'Piece types per position:'),):
+        ppp = "Not a number"
+        for c, t in (
+            (pieces_per_game, "Pieces per position:"),
+            (piecetypes_per_game, "Piece types per position:"),
+        ):
             if positions_per_game:
                 ppp = str(c // positions_per_game)
-            self.report.append_text(' '.join((t, ppp)), timestamp=False)
-        self.report.append_text('', timestamp=False)
+            self.report.append_text(" ".join((t, ppp)), timestamp=False)
+        self.report.append_text("", timestamp=False)
 
         # Check if import can proceed
         if gamecount + errorcount == 0:
             self.report.append_text(
-                'No games, or games with errors, found in import.')
+                "No games, or games with errors, found in import."
+            )
             return False
         if errorcount == 0:
             if estimate:
-                self.report.append_text('No games with errors in sample.')
+                self.report.append_text("No games with errors in sample.")
                 self.report.append_text(
-                    ' '.join(
-                        ('It is estimated no games with',
-                         'errors exist in import.')),
-                    timestamp=False)
+                    " ".join(
+                        (
+                            "It is estimated no games with",
+                            "errors exist in import.",
+                        )
+                    ),
+                    timestamp=False,
+                )
                 self.report.append_text(
-                    'Any found in import will be indexed only as errors.',
-                    timestamp=False)
+                    "Any found in import will be indexed only as errors.",
+                    timestamp=False,
+                )
             else:
-                self.report.append_text('No games with errors in import.')
-            self.report.append_text_only('')
+                self.report.append_text("No games with errors in import.")
+            self.report.append_text_only("")
         elif estimate:
             self.report.append_text(
-                'Games with errors have been found in sample.')
+                "Games with errors have been found in sample."
+            )
             self.report.append_text(
-                ' '.join(
-                    ('The sample is the first',
-                     str(self.sample),
-                     'games in import.')),
-                timestamp=False)
+                " ".join(
+                    (
+                        "The sample is the first",
+                        str(self.sample),
+                        "games in import.",
+                    )
+                ),
+                timestamp=False,
+            )
             self.report.append_text(
-                'All found in import will be indexed only as errors.',
-                timestamp=False)
-            self.report.append_text_only('')
+                "All found in import will be indexed only as errors.",
+                timestamp=False,
+            )
+            self.report.append_text_only("")
         else:
             self.report.append_text(
-                'Games with errors have been found in sample.')
+                "Games with errors have been found in sample."
+            )
             self.report.append_text(
-                'All found in import will be indexed only as errors.',
-                timestamp=False)
-            self.report.append_text_only('')
+                "All found in import will be indexed only as errors.",
+                timestamp=False,
+            )
+            self.report.append_text_only("")
         return bool(self.estimate_data)
 
     # Override ChessException method as ChessUI class is not used.
@@ -524,13 +584,17 @@ class ChessDeferredUpdate(ExceptionHandler):
         """Quit process after import has started."""
         if tkinter.messagebox.askyesno(
             parent=self.root,
-            title='Abandon Import',
-            message=''.join(
-                ('The import has been started.\n\n',
-                 APPLICATION_NAME, ' will attempt ',
-                 'to restore the files using the backups if they were taken.',
-                 '\n\nDo you want to abandon the import?',
-                 ))):
+            title="Abandon Import",
+            message="".join(
+                (
+                    "The import has been started.\n\n",
+                    APPLICATION_NAME,
+                    " will attempt ",
+                    "to restore the files using the backups if they were taken.",
+                    "\n\nDo you want to abandon the import?",
+                )
+            ),
+        ):
             self.root.destroy()
 
     def quit_import(self, event=None):
@@ -541,9 +605,8 @@ class ChessDeferredUpdate(ExceptionHandler):
 
         """
         if tkinter.messagebox.askyesno(
-            parent=self.root,
-            title='Quit Import',
-            message=self._quit_message):
+            parent=self.root, title="Quit Import", message=self._quit_message
+        ):
             self.root.destroy()
 
     def run_allow(self):
@@ -568,65 +631,91 @@ class ChessDeferredUpdate(ExceptionHandler):
         def runjob(*a):
             try:
                 if backup:
-                    self.report.append_text('Taking backups.')
+                    self.report.append_text("Taking backups.")
                     if self.database.archive(flag=backup, names=names) is None:
-                        self.report.append_text('Taking backups abandonned')
+                        self.report.append_text("Taking backups abandonned")
                         self.report.append_text(
-                            ''.join((
-                                'The existing backup does not look like a ',
-                                APPLICATION_NAME, ' backup.')),
-                            timestamp=False)
-                        self.report.append_text_only('')
-                        #self.cancel.configure(
+                            "".join(
+                                (
+                                    "The existing backup does not look like a ",
+                                    APPLICATION_NAME,
+                                    " backup.",
+                                )
+                            ),
+                            timestamp=False,
+                        )
+                        self.report.append_text_only("")
+                        # self.cancel.configure(
                         #    command=self.try_command(
                         #        self.quit_before_import_started, self.cancel))
-                        self._quit_message = ''.join(
-                            ('The import has not been started.',
-                             '\n\nDo you want to abandon the import?',
-                             ))
+                        self._quit_message = "".join(
+                            (
+                                "The import has not been started.",
+                                "\n\nDo you want to abandon the import?",
+                            )
+                        )
                         return
-                    self.report.append_text('Backups saved.')
-                    self.report.append_text_only('')
-                self.report.append_text('Import started.')
-                self.report.append_text_only('')
+                    self.report.append_text("Backups saved.")
+                    self.report.append_text_only("")
+                self.report.append_text("Import started.")
+                self.report.append_text_only("")
                 status = False
                 try:
                     status = self.dumethod(*a)
                 except:
                     write_error_to_log()
-                self.report.append_text('Import finished.')
-                self.report.append_text_only('')
+                self.report.append_text("Import finished.")
+                self.report.append_text_only("")
                 if not status:
                     if backup:
-                        self.report.append_text(''.join(
-                            ('Problem encountered doing import. Backups are ',
-                             'retained for recovery.')))
+                        self.report.append_text(
+                            "".join(
+                                (
+                                    "Problem encountered doing import. Backups are ",
+                                    "retained for recovery.",
+                                )
+                            )
+                        )
                     else:
-                        self.report.append_text(''.join(
-                            ('Problem encountered doing import. No backups ',
-                             'available.')))
+                        self.report.append_text(
+                            "".join(
+                                (
+                                    "Problem encountered doing import. No backups ",
+                                    "available.",
+                                )
+                            )
+                        )
                     self.report.append_text_only(
-                        ''.join(('See ', ERROR_LOG, ' for details.')))
+                        "".join(("See ", ERROR_LOG, " for details."))
+                    )
                 elif backup:
-                    self.report.append_text('Deleting backups.')
-                    if self.database.delete_archive(
-                        flag=backup, names=names) is None:
-                        self.report.append_text('Deleting backups abandonned.')
+                    self.report.append_text("Deleting backups.")
+                    if (
+                        self.database.delete_archive(flag=backup, names=names)
+                        is None
+                    ):
+                        self.report.append_text("Deleting backups abandonned.")
                         self.report.append_text_only(
-                            ''.join((
-                                'The existing backup does not look like a ',
-                                APPLICATION_NAME,
-                                ' backup.')))
+                            "".join(
+                                (
+                                    "The existing backup does not look like a ",
+                                    APPLICATION_NAME,
+                                    " backup.",
+                                )
+                            )
+                        )
                     else:
-                        self.report.append_text('Backups deleted.')
-                #self.cancel.configure(
+                        self.report.append_text("Backups deleted.")
+                # self.cancel.configure(
                 #    command=self.try_command(
                 #        self.quit_after_import_finished, self.cancel),
                 #    text='Quit')
-                self._quit_message = ''.join(
-                    ('The import has been completed.',
-                     '\n\nDo you want to dismiss the import log?',
-                     ))
+                self._quit_message = "".join(
+                    (
+                        "The import has been completed.",
+                        "\n\nDo you want to dismiss the import log?",
+                    )
+                )
             except:
                 try:
                     write_error_to_log()
@@ -640,8 +729,9 @@ class ChessDeferredUpdate(ExceptionHandler):
                 sys.argv[1],
                 sys.argv[2:],
                 self.database.get_file_sizes(),
-                self.report.append_text),
-            )
+                self.report.append_text,
+            ),
+        )
 
     # Methods __call__, get_reportqueue, __run_ui_task_from_queue, and
     # get_thread_queue, introduced to allow this module to work if tkinter is
@@ -660,15 +750,15 @@ class ChessDeferredUpdate(ExceptionHandler):
     # change.
 
     def __call__(self):
-        """"""
+        """ """
         return self
 
     def get_reportqueue(self):
-        """"""
+        """ """
         return self.reportqueue
 
     def get_thread_queue(self):
-        """"""
+        """ """
         return self.queue
 
     def __run_ui_task_from_queue(self, interval):
@@ -680,30 +770,35 @@ class ChessDeferredUpdate(ExceptionHandler):
             except queue.Empty:
                 self.root.after(
                     interval,
-                    self.try_command(
-                        self.__run_ui_task_from_queue, self.root),
-                    *(interval,))
+                    self.try_command(self.__run_ui_task_from_queue, self.root),
+                    *(interval,)
+                )
                 break
             self.reportqueue.task_done()
 
 
 def write_error_to_log():
     """Write the exception to the error log with a time stamp."""
-    f = open(os.path.join(sys.argv[1], ERROR_LOG), 'a')
+    f = open(os.path.join(sys.argv[1], ERROR_LOG), "a")
     try:
         f.write(
-            ''.join(
-                ('\n\n\n',
-                 ' '.join(
-                     (APPLICATION_NAME,
-                      'exception report at',
-                      datetime.datetime.isoformat(datetime.datetime.today())
-                      )),
-                 '\n\n',
-                 traceback.format_exc(),
-                 '\n\n',
-                 ))
+            "".join(
+                (
+                    "\n\n\n",
+                    " ".join(
+                        (
+                            APPLICATION_NAME,
+                            "exception report at",
+                            datetime.datetime.isoformat(
+                                datetime.datetime.today()
+                            ),
+                        )
+                    ),
+                    "\n\n",
+                    traceback.format_exc(),
+                    "\n\n",
+                )
             )
+        )
     finally:
         f.close()
-
