@@ -16,15 +16,14 @@ from .topleveltext import ToplevelText
 
 
 class EngineToplevel(ToplevelText, Engine):
-    
-    """Customize Engine to be the single instance in a Toplevel widget.
-    """
+
+    """Customize Engine to be the single instance in a Toplevel widget."""
 
 
 class EngineToplevelEdit(ToplevelText, EngineEdit):
-    
-    """Customize EngineEdit to be the single instance in a Toplevel widget.
-    """
+
+    """Customize EngineEdit to be the single instance in a Toplevel widget."""
+
     # A method like GameToplevelEdit.create_primary_activity_popup is not
     # needed because the standard edit operations of Text widget are
     # sufficient.
