@@ -5,9 +5,9 @@
 """Import directory of PGN files with gnu.chessgnudu to database."""
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
 
     from .directory_widget import DirectoryWidget
     from ..gnu.chessgnudu import chess_gnudu
 
-    DirectoryWidget(chess_gnudu, 'dbm.gnu')
+    DirectoryWidget(chess_gnudu, "dbm.gnu")
