@@ -13,7 +13,6 @@ from ..core.pgn import GameUpdate
 
 
 class Main(_utilities.Main):
-
     def process_pgn_file(self, event=None):
         """Process PGN file."""
         pr = cProfile.Profile()
@@ -21,16 +20,18 @@ class Main(_utilities.Main):
         super().process_pgn_file(event=event)
         pr.disable()
         s = io.StringIO()
-        ps = pstats.Stats(pr, stream=s).sort_stats('cumulative')
+        ps = pstats.Stats(pr, stream=s).sort_stats("cumulative")
         ps.print_stats()
-        self.insert_text('\nProfile report\n\n')
+        self.insert_text("\nProfile report\n\n")
         self.insert_text(s.getvalue())
         self.root.wm_resizable(width=tkinter.TRUE, height=tkinter.TRUE)
         self.root.columnconfigure(0, weight=1)
         self.text.pack(expand=tkinter.TRUE, fill=tkinter.BOTH)
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
 
-    Main(game_class=GameUpdate,
-         samples_title='Sample ChessTab Update Profile Report').root.mainloop()
+    Main(
+        game_class=GameUpdate,
+        samples_title="Sample ChessTab Update Profile Report",
+    ).root.mainloop()
